summaryrefslogtreecommitdiff
path: root/packages/sys-boot/dracut/files/0008-dracut-044-ext4-and-f2fs-need-crc32X-too.patch
blob: dad12c9b65174bc358697a0316b590e2b712e05f (plain)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
diff -Naur dracut-044/modules.d/99fs-lib/module-setup.sh dracut-044-p/modules.d/99fs-lib/module-setup.sh
--- dracut-044/modules.d/99fs-lib/module-setup.sh	2015-11-25 14:22:28.000000000 +0100
+++ dracut-044-p/modules.d/99fs-lib/module-setup.sh	2018-04-26 16:30:19.960345610 +0200
@@ -38,20 +38,23 @@
 include_fs_helper_modules() {
     local dev=$1 fs=$2
     case "$fs" in
-        xfs|btrfs)
+        xfs|btrfs|ext4)
             instmods crc32c
             ;;
+        f2fs)
+            instmods crc32
+            ;;
     esac
 }
 
 # called by dracut
 installkernel() {
     # xfs and btrfs needs crc32c...
     if [[ $hostonly ]]; then
         for_each_host_dev_fs include_fs_helper_modules
         :
     else
-        instmods crc32c
+        instmods crc32c crc32
     fi
 }
@@ -38,20 +38,23 @@
 # called by dracut
 installkernel() {
-    # xfs and btrfs needs crc32c...
+    # xfs, btrfs , ext4, f2fs needs crc32c / crc32
     if [[ $hostonly ]]; then
         for_each_host_dev_fs include_fs_helper_modules